==> xiaomi_flashable_firmware_creator_gui-2.0.1-py3-none-any.whl: README.md <==
## Xiaomi Flashable Firmware Creator GUI

Create flashable firmware zip from MIUI Recovery ROMs!

[![Crowdin](https://badges.crowdin.net/mi-flashable-firmware-creator/localized.svg)](https://crowdin.com/project/mi-flashable-firmware-creator)

[![PyPI version](https://badge.fury.io/py/xiaomi-flashable-firmware-creator-gui.svg)](https://pypi.org/project/xiaomi-flashable-firmware-creator-gui/)
[![made-with-python](https://img.shields.io/badge/Made%20with-Python%203-3776AB?style=flat\&labelColor=3776AB\&logo=python\&logoColor=white\&link=https://www.python.org/)](https://www.python.org/)
[![Codacy Badge](https://app.codacy.com/project/badge/Grade/9c1f6cee01b74ef8a2fd0f0c787596a8)](https://www.codacy.com/gh/XiaomiFirmwareUpdater/xiaomi-flashable-firmware-creator.py/dashboard?utm_source=github.com\&utm_medium=referral\&utm_content=XiaomiFirmwareUpdater/xiaomi-flashable-firmware-creator.py\&utm_campaign=Badge_Grade)
[![Open Source Love](https://badges.frapsoft.com/os/v3/open-source.svg?v=103)](#) <br />
[![PayPal](https://img.shields.io/badge/PayPal-Donate-00457C?style=flat\&labelColor=00457C\&logo=PayPal\&logoColor=white\&link=https://www.paypal.me/yshalsager)](https://www.paypal.me/yshalsager)
[![Patreon](https://img.shields.io/badge/Patreon-Support-F96854?style=flat\&labelColor=F96854\&logo=Patreon\&logoColor=white\&link=https://www.paypal.me/yshalsager)](https://www.paypal.me/yshalsager)
[![Liberapay](https://img.shields.io/badge/Liberapay-Support-F6C915?style=flat\&labelColor=F6C915\&logo=Liberapay\&logoColor=white\&link=https://liberapay.com/yshalsager)](https://liberapay.com/yshalsager)

Xiaomi Flashable Firmware Creator is a tool that generates flashable firmware-update packages from official MIUI ROMS.

It supports creating untouched firmware, non-arb firmware, firmware + vendor flashable zip, and firmware-less ROMs.
[![screenshot](https://raw.githubusercontent.com/XiaomiFirmwareUpdater/xiaomi-flashable-firmware-creator-gui/master/screenshots/1.png)](https://xiaomifirmwareupdater.com/projects/xiaomi-flashable-firmware-creator/)

### Features:

*   Easy-to-use interface
*   Multilanguage support (more than 25 languages!). Thanks to our community members!

#### Screenshots:

[Here](https://github.com/XiaomiFirmwareUpdater/xiaomi-flashable-firmware-creator-gui/tree/master/screenshots)

### Installation

You can simply install this tool using Python pip.

```shell script
pip install xiaomi_flashable_firmware_creator_gui
```

**Manual Installation**

*   Clone this repo using `git clone --recursive`
*   Make sure that you have Python3 installed on your device.
*   Install the required packages.

```shell script
pip3 install -r requirements.txt
```

### GUI Usage:

*   Run the tool.

```shell script
python3 -m xiaomi_flashable_firmware_creator_gui
```

==> xiaomi_flashable_firmware_creator_gui-2.3.0-py3-none-any.whl: README.md <==
## Xiaomi Flashable Firmware Creator GUI

Create flashable firmware zip from MIUI Recovery ROMs!

[![Crowdin](https://badges.crowdin.net/mi-flashable-firmware-creator/localized.svg)](https://crowdin.com/project/mi-flashable-firmware-creator)

[![PyPI version](https://badge.fury.io/py/xiaomi-flashable-firmware-creator-gui.svg)](https://pypi.org/project/xiaomi-flashable-firmware-creator-gui/)
[![made-with-python](https://img.shields.io/badge/Made%20with-Python%203-3776AB?style=flat\&labelColor=3776AB\&logo=python\&logoColor=white\&link=https://www.python.org/)](https://www.python.org/)
[![Open Source Love](https://badges.frapsoft.com/os/v3/open-source.svg?v=103)](#) <br />
[![PayPal](https://img.shields.io/badge/PayPal-Donate-00457C?style=flat\&labelColor=00457C\&logo=PayPal\&logoColor=white\&link=https://www.paypal.me/yshalsager)](https://www.paypal.me/yshalsager)
[![Patreon](https://img.shields.io/badge/Patreon-Support-F96854?style=flat\&labelColor=F96854\&logo=Patreon\&logoColor=white\&link=https://www.paypal.me/yshalsager)](https://www.paypal.me/yshalsager)
[![Liberapay](https://img.shields.io/badge/Liberapay-Support-F6C915?style=flat\&labelColor=F6C915\&logo=Liberapay\&logoColor=white\&link=https://liberapay.com/yshalsager)](https://liberapay.com/yshalsager)

Xiaomi Flashable Firmware Creator is a tool that generates flashable firmware-update packages from official MIUI ROMS.

It supports creating untouched firmware, non-arb firmware, firmware + vendor flashable zip, and firmware-less ROMs.
[![screenshot](https://raw.githubusercontent.com/XiaomiFirmwareUpdater/xiaomi-flashable-firmware-creator-gui/master/screenshots/1.png)](https://xiaomifirmwareupdater.com/projects/xiaomi-flashable-firmware-creator/)

### Features:

*   Easy-to-use interface
*   Multilanguage support (more than 25 languages!). Thanks to our community members!

#### Screenshots:

[Here](https://github.com/XiaomiFirmwareUpdater/xiaomi-flashable-firmware-creator-gui/tree/master/screenshots)

### Installation

**Using pip**
You can simply install this tool using Python pip.

```shell script
pip install xiaomi_flashable_firmware_creator_gui
```

**Manual Installation**

*   Clone this repo using `git clone`
*   Make sure that you have Python3 installed with pip version higher than 19 on your device.
*   Install the required packages by running the following command in cloned repo folder.

```shell script
pip3 install .
```

### GUI Usage:

*   Run the tool.

```shell script
xiaomi_flashable_firmware_creator_gui
```
